@@ -165,8 +165,16 @@ class Camera(BaseCamera):
             timeoutok = False
             ret = False
             frame = None
+            if type(cap) == tuple:
+                print("TUPLE cap:",cap)
+                cap = cap[0] # THIS IS STRANGE FOR newcam20211117
+                print("new:", cap , type(cap) )
+
             if (cap is None) or (not cap.isOpened()):
-                print("X... camera None or not Opened(real)")
+                print("X... camera is None ")
+                ret = False
+            elif not cap.isOpened():
+                print("X... camera  not Opened(real)")
                 ret = False
             else:
                 try: #----this catches errors of libjpeg with cv2.CAP_V4L2
