@@ -211,6 +211,7 @@ def display2(videodev, save = False,
     """
     #sname,sfilenamea,sme,sfilenamea,sfilenamea,sfourcc,saviout
 
+    sme = socket.gethostname()
     def setupsave():
         sname = "rec"
         sname = videodev
@@ -290,7 +291,7 @@ def display2(videodev, save = False,
 
         mjpg =False
 
-        rpiName = socket.gethostname()
+
         # #===================== OPENCV START CAPTURE==========================
 
         bytex = b'' # stream
@@ -483,12 +484,17 @@ def display2(videodev, save = False,
                 frames_total+= 1
                 # cv2.namedWindow( wname, cv2.WINDOW_KEEPRATIO ,cv2.WINDOW_GUI_EXPANDED)
                 cv2.namedWindow( wname , cv2.WINDOW_KEEPRATIO ) # 2 may allow resize on gigavg
+                # cv2.namedWindow( wname , 2 ) # 2 may allow resize on gigavg
                 if frames_total < 2:
                     #cv2.namedWindow(wname,cv2.WND_PROP_FULLSCREEN)
                     # ?https://stackoverflow.com/questions/62870031/pixel-coordinates-and-colours-not-showing
                     # TRICK !!!!!!!!!!!!
                     # https://stackoverflow.com/a/52776376
                     cv2.setWindowProperty(wname, cv2.WND_PROP_FULLSCREEN, cv2.WINDOW_FULLSCREEN)
+                    bit_fs = 0
+                    if sme in ['gigavg','vaio']:
+                        bit_fs =1
+                    cv2.setWindowProperty(wname, cv2.WND_PROP_FULLSCREEN,  bit_fs)
                     cv2.resizeWindow(wname, frame.shape[1], frame.shape[0] )
 
                 if save:
@@ -540,7 +546,7 @@ def display2(videodev, save = False,
                     sname = "snapshot"
                     saved_jpg = True
                     sfilename = dt.datetime.now().strftime("%Y%m%d_%H%M%S")
-                    sme = socket.gethostname()
+                    # defined above # sme = socket.gethostname()
                     sfilename = f"{sme}{sname}_{sfilename}.jpg"
                     sfilename = os.path.expanduser( "~/"+sfilename )
                     # sfourcc = cv2.VideoWriter_fourcc(*'XVID')
